package org.rcisoft.app.appActivity.controller;


/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import org.rcisoft.business.cmsActivity.entity.CmsActivity;
import org.rcisoft.business.cmsActivity.service.CmsActivityService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * @author cy
 * @date 2024年3月25日 下午1:42:40
 */
@RestController
@RequestMapping("/app")
public class AppActivityController extends CyPaginationController<CmsActivity> {


    @Autowired
    private CmsActivityService cmsActivityServiceImpl;

    /**
     * 活动-查看活动详情
     */
    @CyOpeLogAnno(title = "system-活动管理-查询活动", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "查询单一活动", description = "查询单一活动")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @GetMapping("/open/cmsActivity/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivityServiceImpl.findById(businessId));
    }

    /**
     * 活动-查看活动列表
     */
    @CyOpeLogAnno(title = "system-活动管理-查询活动", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "分页查询活动集合", description = "分页查询活动集合")
    @GetMapping(value = "/open/cmsActivity/queryCmsActivityByPagination")
    public CyGridModel listByPagination(CmsActivity cmsActivity) {
        cmsActivityServiceImpl.findAllByPagination(getPaginationUtility(), cmsActivity,"app");
        return getGridModelResponse();
    }

    /**
     * 活动-查询是否已报名
     */
    @CyOpeLogAnno(title = "system-活动管理-查询是否已报名", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "查询是否已报名", description = "查询是否已报名")
    @GetMapping(value = "/cmsActivity/getActivityIsApplication")
    public CyResult getActivityIsApplication(Integer activityId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsActivityServiceImpl.getIsApplication(activityId));
    }
}
