package org.rcisoft.app.appMemGoldCoinFlow.controller;


/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.servlet.http.HttpServletResponse;
import org.rcisoft.business.memGoldCoinFlow.entity.MemGoldCoinFlow;
import org.rcisoft.business.memGoldCoinFlow.service.MemGoldCoinFlowService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
* Created by cy on 2025年2月7日 上午10:11:22.
*/
@RestController
@RequestMapping("/app")
public class AppMemGoldCoinFlowController extends CyPaginationController<MemGoldCoinFlow> {


    @Autowired
    private MemGoldCoinFlowService memGoldCoinFlowServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('app:goldCoinFlow:add')")
    @CyOpeLogAnno(title = "system-金币流水表管理-新增金币流水表", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加金币流水表", description="添加金币流水表")
    @PostMapping(value = "/memGoldCoinFlow/add")
    public CyResult add(@Valid @RequestBody MemGoldCoinFlow memGoldCoinFlow, BindingResult bindingResult) {
        CyPersistModel data = memGoldCoinFlowServiceImpl.persist(memGoldCoinFlow);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memGoldCoinFlow);
    }

    @CyOpeLogAnno(title = "system-goldCoinFlow管理-查询goldCoinFlow管理", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询当前用户金币余额", description="查询当前用户金币余额")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @GetMapping("/memGoldCoinFlow/balance")
    public CyResult balance() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                memGoldCoinFlowServiceImpl.balance());
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:list')")
    @CyOpeLogAnno(title = "system-金币流水表管理-查询金币流水表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询金币流水表集合", description="分页查询金币流水表集合")
    @GetMapping(value = "/memGoldCoinFlow/list")
    public CyGridModel listByPagination(MemGoldCoinFlow memGoldCoinFlow) {
        memGoldCoinFlowServiceImpl.findAllByPagination(getPaginationUtility(), memGoldCoinFlow,"app");
        return getGridModelResponse();
    }
}
