package org.rcisoft.app.appMemLeaveMessage.controller;


/*固定导入*/

import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.media.Schema;
import org.rcisoft.business.memGoldCoinFlow.entity.MemGoldCoinFlow;
import org.rcisoft.business.memLeaveMessage.entity.MemLeaveMessage;
import org.rcisoft.business.memLeaveMessage.service.impl.MemLeaveMessageServiceImpl;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
* Created by cy on 2024年12月20日 下午3:35:34.
*/
@RestController
@RequestMapping("/app")
public class AppMemLeaveMessageController extends CyPaginationController<MemLeaveMessage> {


    @Autowired
    private MemLeaveMessageServiceImpl memLeaveMessageServiceImpl;


    /**
     * 用户详情/我的-留言
     */
    @PreAuthorize("@cyPerm.hasPerm('app:mem:leaveMessage')")
    @CyOpeLogAnno(title = "system-会员表管理-留言", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="留言", description="留言")
    @PostMapping(value = "/memLeaveMessage/leaveMessage")
    public CyResult leaveMessage(@Valid @RequestBody MemLeaveMessage memLeaveMessage, BindingResult bindingResult) {
        CyPersistModel data = memLeaveMessageServiceImpl.leaveMessage(memLeaveMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                memLeaveMessage);
    }

    /**
     * 分页查询留言列表
     */
    @PreAuthorize("@cyPerm.hasPerm('app:mem:query')")
    @CyOpeLogAnno(title = "system-会员表管理-查询对话表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询对话列表", description="分页查询对话列表")
    @GetMapping(value = "/memLeaveMessage/talkList")
    public CyGridModel queryTalkByPagination(MemLeaveMessage memLeaveMessage) {
        IPage<MemLeaveMessage> memUserTalkIPage = memLeaveMessageServiceImpl.queryTalkByPagination(getPaginationUtility(), memLeaveMessage);
        return getGridModelResponse();
    }

    /**
     * 查询留言列表详情 1对1的
     */
    @PreAuthorize("@cyPerm.hasPerm('app:mem:query')")
    @CyOpeLogAnno(title = "system-会员表管理-查询留言详情列表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询留言详情列表", description="分页查询留言详情列表")
    @GetMapping(value = "/memLeaveMessage/leaveMessageDetailList")
    public CyGridModel leaveMessageDetailList(MemLeaveMessage memLeaveMessage) {
        IPage<MemLeaveMessage> userLeaveMessage = memLeaveMessageServiceImpl.leaveMessageDetailByPagination(getPaginationUtility(), memLeaveMessage);
        return getGridModelResponse();
    }

    /**
     * 删除对话表
     */
    @PreAuthorize("@cyPerm.hasPerm('app:mem:delete')")
    @CyOpeLogAnno(title = "system-对话管理-删除对话表", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="删除对话表", description="删除对话表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/memLeaveMessage/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, MemLeaveMessage memLeaveMessage) {
        memLeaveMessage.setBusinessId(businessId);
        CyPersistModel data = memLeaveMessageServiceImpl.deleteMessage(memLeaveMessage);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    /**
     * 我的留言-查询留言未读消息数量
     */
    @PreAuthorize("@cyPerm.hasPerm('app:mem:query')")
    @CyOpeLogAnno(title = "system-留言管理-查询留言未读消息数量", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary = "查询留言未读消息数量", description = "查询留言未读消息数量")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true)})
    @GetMapping("/memLeaveMessage/noReadMessageAllCount")
    public CyResult noReadMessageAllCount() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                memLeaveMessageServiceImpl.noReadMessageAllCount());
    }
}
