package org.rcisoft.app.appOpmBlackList.controller;


/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.servlet.http.HttpServletResponse;
import org.rcisoft.business.opmBlacklist.entity.OpmBlackList;
import org.rcisoft.business.opmBlacklist.service.OpmBlackListService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
* Created by cy on 2025年2月10日 上午9:46:37.
*/
@RestController
@RequestMapping("/app")
public class AppOpmBlackListController extends CyPaginationController<OpmBlackList> {


    @Autowired
    private OpmBlackListService opmBlackListServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('app:blackList:add')")
    @CyOpeLogAnno(title = "system-黑名单表管理-新增黑名单表", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加黑名单表", description="添加黑名单表")
    @PostMapping(value = "/opmBlackList/add")
    public CyResult add(@Valid @RequestBody OpmBlackList opmBlackList, BindingResult bindingResult) {
        CyPersistModel data = opmBlackListServiceImpl.persist(opmBlackList);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        opmBlackList);
    }

    @PreAuthorize("@cyPerm.hasPerm('app:blackList:list')")
    @CyOpeLogAnno(title = "system-黑名单表管理-查询黑名单表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询黑名单表集合", description="分页查询黑名单表集合")
    @GetMapping(value = "/opmBlackList/list")
    public CyGridModel listByPagination(OpmBlackList opmBlackList) {
        opmBlackListServiceImpl.findAllByPagination(getPaginationUtility(), opmBlackList);
        return getGridModelResponse();
    }


    @PreAuthorize("@cyPerm.hasPerm('app:blackList:delete')")
    @CyOpeLogAnno(title = "system-黑名单表管理-删除黑名单表", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="删除黑名单表", description="删除黑名单表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/opmBlackList/delete")
    public CyResult delete(@RequestBody OpmBlackList opmBlackList) {
        CyPersistModel data = opmBlackListServiceImpl.remove(opmBlackList);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                opmBlackList);
    }
}
