package org.rcisoft.app.login.controller;

import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.app.login.service.WxMiniService;
import org.rcisoft.core.jwt.util.CyJwtUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @author cy
 * Created by cy on 21/5/10.
 * @descript
 */
@RestController
@RequestMapping("/app/wxMiniApp")
@Slf4j
public class WxMiniAppController {

    @Autowired
    private WxMiniService wxMiniServiceImpl;

    @Autowired
    private CyJwtUtil cyJwtUtil;


    /**
     * wx login  第一步
     * 1. 小程序刚进入的时候，可能会有token
     * 2. 手机号登录，之前调用的
     *
     * @param code code
     * @return
     */
    @GetMapping("/validLogin")
    public Map<String, Object> validLogin(@RequestParam("code") String code, HttpServletRequest request) {
        // 1. 已经登录 ----> 延长登录过期时间 30分钟，返回token 和 基本信息(身份)
        return wxMiniServiceImpl.validLogin(code, cyJwtUtil.getToken(request));
    }

    /**
     * 手机号登录  第二步
     *
     * @return
     */
    @GetMapping("/phoneLogin")
    public Map<String, Object> phoneLogin(@RequestParam("encryptedData") String encryptedData,
                                          @RequestParam("iv") String iv,
                                          @RequestParam("openId") String openId) {
        return wxMiniServiceImpl.phoneLogin(encryptedData, iv, openId);
    }


    /**
     * 保存授权信息 第三步
     *
     * @return
     */
    @PostMapping("/saveUserProfile")
    public Map<String, Object> saveUserProfile(HttpServletRequest request,
                                               @RequestParam("nickName") String nickName,
                                               @RequestParam("avatarUrl") String avatarUrl,
                                               @RequestParam("gender") String gender,
                                               @RequestParam("address") String address) {
        return wxMiniServiceImpl.saveUserProfile(nickName, avatarUrl, gender, address, cyJwtUtil.getToken(request));
    }


}
